@@ -18,7 +18,9 @@ def query_to_frame(query, index_col=None, include_hybrid=False) -> pd.DataFrame:
     """
     if include_hybrid:
         return objects_to_frame(query.all(), include_hybrid=True)
-    return pd.read_sql(query.statement, query.session.bind, index_col=index_col)
+    return drop_duplicate_columns(
+        pd.read_sql(query.statement, query.session.bind, index_col=index_col)
+    )
 
 
 def objects_to_frame(objs, index_col=None, include_hybrid=False) -> pd.DataFrame:
@@ -33,3 +35,7 @@ def objects_to_frame(objs, index_col=None, include_hybrid=False) -> pd.DataFrame
     return pd.DataFrame.from_records(
         [xx.as_dict(include_hybrid=include_hybrid) for xx in objs], index=index_col
     )
+
+
+def drop_duplicate_columns(df):
+    return df.loc[:, ~df.columns.duplicated()]
